@@ -4,7 +4,7 @@ import pyqtgraph as pg
 import numpy as np
 from functools import partial
 
-from PyQt5.QtWidgets import (QWidget, QGridLayout, QLabel, 
+from PyQt5.QtWidgets import (QWidget, QFrame, QGridLayout, QLabel, 
                              QRadioButton,
                              QApplication, QPushButton, QScrollBar,
                              QMainWindow, QMenu, QAction, QVBoxLayout,
@@ -114,16 +114,20 @@ class ColorBarItemMouse(pg.ColorBarItem, Observable):
         
 
         
-class WidgetBase(QWidget, Observable):
+class WidgetBase(QFrame, Observable):
 
     _layout = None
-    def __init__(self, parent=None):
-        QWidget.__init__(self, parent)
+    def __init__(self, *args, **kwargs):
+        QFrame.__init__(self, *args, **kwargs)
         Observable.__init__(self, log_level=LOG_LEVEL)
         self.create_widgets()
         self.create_layout()
         self.set_callbacks()
         self.setLayout(self.layout)
+        self.set_style()
+        
+    def set_style(self):
+        pass
         
     def create_widgets(self):
         pass
@@ -464,10 +468,9 @@ class ButtonView(WidgetBase):
         self._buttons[index].setEnabled(enabled)
 
    
-class RadioButtonView(ButtonView):
-    EVENT = 'selection_change'
-    label_text = 'Radiobutton Group Name'
-    button_texts = ['RadioButton1', 'RadioButton2']
+class RadioButtonView(ButtonView):    
+    label_text      = 'Radiobutton Group Name'
+    button_texts    = ['RadioButton1', 'RadioButton2']
     
     def __init__(self, parent=None, button_texts=None, label_text=None,
                  selected_button=None):
